/*----------------------------------------------------------------------
copyright (c) 2008 Georget Fabien

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
--------------------------------------------------------------------------
File : InfoTab.h
Program : gt2n
Date : 10/07/08
--------------------------------------------------------------------------
Nature : Header file for the MainWindow class
--------------------------------------------------------------------------*/
 
#ifndef MAINWINDOW_H
 #define MAINWINDOW_H

 #include <QMainWindow>
 #include <QAction>
 #include "errors.h"
 #include "errormng.h"
 #include "usbmisc.h"
 #include "usbnxt.h"

 class QMenu;
 class QMdiArea;
 class QMdiSubWindow;
 class MdiChild;
 class QSignalMapper;
 class QLabel;
 class InfoTab;
 class ExploTab;
 class CompDock;
 class QString;
class Highlighter;

 class MainWindow : public QMainWindow
 {
     Q_OBJECT

 public:
     MainWindow();
    void afficherMessage(QString message,int time=2000);
    void connectBrick();
    void renameBrick();
    nxt_info getInfo();
    nxt_file getFirstFile();
    nxt_file getNextFile(char handle);
    void closeSearchFile(char handle);
    void deleteFile(QString filename);
    void downloadFile(QString fpath);
    void uploadFile(QString fpath);
   //this method is VERY important to know if we can call the brick ! 
    bool brickIsHere();
    bool highlightIsChecked(){return highlightAct->isChecked();}

 protected:
     void closeEvent(QCloseEvent *event);

 private slots:
     void newFile();
     void open();
     void save();
     void saveAs();
     void cut();
     void copy();
     void paste();
     void undo();
     void redo();
     void about();
     void highlight();
     void updateMenus();
     void updateWindowMenu();
     MdiChild *createMdiChild();
     void setActiveSubWindow(QWidget *window);
  
    void s_connectBrick();
    void s_disconnectBrick();
    void s_renameBrick();
    void s_uploadFile();
    void s_compile();
    void s_transfert();

 private:
      
     void createActions();
     void createMenus();
     void createToolBars();
     void createStatusBar();
     void createDock();
     void messError(QString message,QString action);
     void actEnableConnect(bool boolean);
     MdiChild *activeMdiChild();
     QMdiSubWindow *findMdiChild(const QString &fileName);
    
     UsbNxt *zeBrick;
     bool isConnected;
     QLabel *labelEtat;
     QMdiArea *mdiArea;
     QSignalMapper *windowMapper;

     InfoTab *infoDock;
     ExploTab *exploDock;
     CompDock *compDock;

     QMenu *fileMenu;
     QMenu *editMenu;
     QMenu *windowMenu;
     QMenu *helpMenu;
     QMenu *brickMenu;
     QMenu *explorerMenu;
     QMenu *compilerMenu;
     QToolBar *fileToolBar;
     QToolBar *editToolBar;
     QToolBar *brickToolBar;
     QAction *newAct;
     QAction *openAct;
     QAction *saveAct;
     QAction *saveAsAct;
     QAction *exitAct;
     QAction *undoAct;
     QAction *redoAct;
     QAction *cutAct;
     QAction *copyAct;
     QAction *pasteAct;
     QAction *closeAct;
     QAction *closeAllAct;
     QAction *tileAct;
     QAction *cascadeAct;
     QAction *nextAct;
     QAction *previousAct;
     QAction *separatorAct;
     QAction *aboutAct;
     QAction *aboutQtAct;
     QAction *highlightAct;
     QAction *actionConnect;
     QAction *actionDeconnect;
     QAction *actionRefresh;
     QAction *actionRename;
     QAction *actionUpload;
     QAction *actionCompile;
     QAction *actionTransfert;
     QAction *actionCleanLog;
     QAction *actionSaveLog;
     QStatusBar *barreEtat;
     QAction *actionDelete;


 };

 #endif